use clap::Parser;
use std::env;
use std::process::exit;
use std::str::FromStr;

use crate::commands::{Cli, Command};
use log::{info, SetLoggerError};

mod commands;
mod package;

fn main() {
    setup_logger().expect("Unable to setup logger.");

    let c = Cli::parse();
    info!("Command: {:?}", c);
}

fn setup_logger() -> Result<(), SetLoggerError> {
    fern::Dispatch::new()
        .format(|out, message, record| {
            out.finish(format_args!(
                "{} {}",
                match record.level().to_string().chars().nth(0).unwrap_or('I') {
                    'E' | 'W' => "!!",
                    _ => "**",
                },
                message
            ))
        })
        .level(log::LevelFilter::Info)
        .chain(std::io::stdout())
        .apply()
}
